@@ -22,7 +22,7 @@ class Bailador::App is Bailador::Route {
     method request  { $.context.request  }
     method response { $.context.response }
     method template(Str $tmpl, Str :$layout, *@params, *%params) {
-        my $content = $!renderer.render("$.location/views/$tmpl", |@params, |%params);
+        my $content = $!renderer.render("$.location/" ~ self.config.views ~ "/$tmpl", |@params, |%params);
 
         my $use-this-layout = $layout // $.config.layout;
         if $use-this-layout {
@@ -79,6 +79,24 @@ class Bailador::App is Bailador::Route {
         self!sessions.store(self.response, self.request.env);
     }
 
+    multi method baile() {
+        my $command;
+        if $.config.default-command() {
+            $command = $.config.default-command();
+        } elsif $.config.command-detection() {
+            $command = $.commands.detect-command();
+        } else {
+            die 'can not detect command';
+        }
+        self.baile($command);
+    }
+
+    multi method baile(Str $command, *@args) {
+        my $cmd = $.commands.get-command($command);
+        $.config.load-from-args(@args),
+        return $cmd.run(app => self);
+    }
+
     method get-psgi-app {
         # quotes from https://github.com/zostay/P6SGI
         # draft 0.7
