@@ -2,7 +2,7 @@ use v6;
 
 use Bailador::Command::p6w;
 use Bailador::Command::easy;
-
+use Bailador::Command::watch;
 
 class Bailador::Commands {
     has @.namespaces = ( 'Bailador::Command' );
@@ -29,10 +29,10 @@ class Bailador::Commands {
 
     method detect-command() {
         if %*ENV<P6SGI_CONTAINER> || %*ENV<P6W_CONTAINER> {
-            self.get-command('p6w');
+            'p6w';
         }
         else {
-            self.get-command('easy');
+            'easy'
         }
     }
 }
